package com.ruoyi.ems.service;

import java.util.List;
import com.ruoyi.ems.domain.AdmEmsIndexRange;

/**
 * 能源指标范围Service接口
 * 
 * @author ruoyi
 * @date 2024-08-30
 */
public interface IAdmEmsIndexRangeService 
{
    /**
     * 查询能源指标范围
     * 
     * @param id 能源指标范围主键
     * @return 能源指标范围
     */
    public AdmEmsIndexRange selectAdmEmsIndexRangeById(Long id);

    /**
     * 查询能源指标范围列表
     * 
     * @param admEmsIndexRange 能源指标范围
     * @return 能源指标范围集合
     */
    public List<AdmEmsIndexRange> selectAdmEmsIndexRangeList(AdmEmsIndexRange admEmsIndexRange);

    /**
     * 新增能源指标范围
     * 
     * @param admEmsIndexRange 能源指标范围
     * @return 结果
     */
    public int insertAdmEmsIndexRange(AdmEmsIndexRange admEmsIndexRange);

    /**
     * 修改能源指标范围
     * 
     * @param admEmsIndexRange 能源指标范围
     * @return 结果
     */
    public int updateAdmEmsIndexRange(AdmEmsIndexRange admEmsIndexRange);

    /**
     * 批量删除能源指标范围
     * 
     * @param ids 需要删除的能源指标范围主键集合
     * @return 结果
     */
    public int deleteAdmEmsIndexRangeByIds(Long[] ids);

    /**
     * 删除能源指标范围信息
     * 
     * @param id 能源指标范围主键
     * @return 结果
     */
    public int deleteAdmEmsIndexRangeById(Long id);
}
